@@ -8,6 +8,7 @@ use ArrayIterator;
 use InvalidArgumentException;
 use Laminas\Stdlib\ArrayObject;
 use PHPUnit\Framework\TestCase;
+use RecursiveArrayIterator;
 use TypeError;
 
 use function asort;
@@ -21,8 +22,6 @@ use function uasort;
 use function uksort;
 use function unserialize;
 
-use const PHP_MAJOR_VERSION;
-
 class ArrayObjectTest extends TestCase
 {
     public function testConstructorDefaults(): void
@@ -37,10 +36,10 @@ class ArrayObjectTest extends TestCase
 
     public function testConstructorParameters(): void
     {
-        $ar = new ArrayObject(['foo' => 'bar'], ArrayObject::ARRAY_AS_PROPS, 'RecursiveArrayIterator');
+        $ar = new ArrayObject(['foo' => 'bar'], ArrayObject::ARRAY_AS_PROPS, RecursiveArrayIterator::class);
         self::assertEquals(ArrayObject::ARRAY_AS_PROPS, $ar->getFlags());
-        self::assertEquals('RecursiveArrayIterator', $ar->getIteratorClass());
-        self::assertInstanceOf('RecursiveArrayIterator', $ar->getIterator());
+        self::assertEquals(RecursiveArrayIterator::class, $ar->getIteratorClass());
+        self::assertInstanceOf(RecursiveArrayIterator::class, $ar->getIterator());
         self::assertSame(['foo' => 'bar'], $ar->getArrayCopy());
         self::assertEquals(1, $ar->count());
         self::assertSame('bar', $ar->foo);
@@ -49,6 +48,7 @@ class ArrayObjectTest extends TestCase
 
     public function testStdPropList(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar      = new ArrayObject();
         $ar->foo = 'bar';
         $ar->bar = 'baz';
@@ -63,12 +63,14 @@ class ArrayObjectTest extends TestCase
     public function testStdPropListCannotAccessObjectVars(): void
     {
         $this->expectException(InvalidArgumentException::class);
+        /** @var ArrayObject<array-key, mixed> $ar */
         $ar = new ArrayObject();
         $ar->flag;
     }
 
     public function testStdPropListStillHandlesArrays(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar        = new ArrayObject();
         $ar->foo   = 'bar';
         $ar['foo'] = 'baz';
@@ -80,6 +82,7 @@ class ArrayObjectTest extends TestCase
 
     public function testArrayAsProps(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar        = new ArrayObject([], ArrayObject::ARRAY_AS_PROPS);
         $ar->foo   = 'bar';
         $ar['foo'] = 'baz';
@@ -94,6 +97,7 @@ class ArrayObjectTest extends TestCase
 
     public function testAppend(): void
     {
+        /** @var ArrayObject<int, string> $ar */
         $ar = new ArrayObject(['one', 'two']);
         self::assertEquals(2, $ar->count());
 
@@ -112,25 +116,8 @@ class ArrayObjectTest extends TestCase
         self::assertSame($sorted, $ar->getArrayCopy());
     }
 
-    public function testCountRaisesWarningUnderPhpSeven(): void
-    {
-        if (PHP_MAJOR_VERSION > 7) {
-            $this->markTestSkipped('This test only makes sense under PHP 7');
-        }
-
-        $ar = new ArrayObject(new TestAsset\ArrayObjectObjectVars());
-
-        $this->expectWarning();
-        $this->expectExceptionMessage('Parameter must be an array or an object that implements Countable');
-        self::assertCount(1, $ar);
-    }
-
     public function testCountRaisesTypeErrorUnderPhpEight(): void
     {
-        if (PHP_MAJOR_VERSION < 8) {
-            $this->markTestSkipped('This test only makes sense under PHP 8 and above');
-        }
-
         $ar = new ArrayObject(new TestAsset\ArrayObjectObjectVars());
 
         $this->expectException(TypeError::class);
@@ -146,6 +133,7 @@ class ArrayObjectTest extends TestCase
 
     public function testExchangeArray(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar  = new ArrayObject(['foo' => 'bar']);
         $old = $ar->exchangeArray(['bar' => 'baz']);
 
@@ -227,14 +215,14 @@ class ArrayObjectTest extends TestCase
 
     public function testIteratorClass(): void
     {
-        $ar = new ArrayObject([], ArrayObject::STD_PROP_LIST, 'RecursiveArrayIterator');
-        self::assertEquals('RecursiveArrayIterator', $ar->getIteratorClass());
-        $ar = new ArrayObject([], ArrayObject::STD_PROP_LIST, 'ArrayIterator');
-        self::assertEquals('ArrayIterator', $ar->getIteratorClass());
-        $ar->setIteratorClass('RecursiveArrayIterator');
-        self::assertEquals('RecursiveArrayIterator', $ar->getIteratorClass());
-        $ar->setIteratorClass('ArrayIterator');
-        self::assertEquals('ArrayIterator', $ar->getIteratorClass());
+        $ar = new ArrayObject([], ArrayObject::STD_PROP_LIST, RecursiveArrayIterator::class);
+        self::assertEquals(RecursiveArrayIterator::class, $ar->getIteratorClass());
+        $ar = new ArrayObject([], ArrayObject::STD_PROP_LIST, ArrayIterator::class);
+        self::assertEquals(ArrayIterator::class, $ar->getIteratorClass());
+        $ar->setIteratorClass(RecursiveArrayIterator::class);
+        self::assertEquals(RecursiveArrayIterator::class, $ar->getIteratorClass());
+        $ar->setIteratorClass(ArrayIterator::class);
+        self::assertEquals(ArrayIterator::class, $ar->getIteratorClass());
     }
 
     public function testInvalidIteratorClassThrowsInvalidArgumentException(): void
@@ -272,6 +260,7 @@ class ArrayObjectTest extends TestCase
 
     public function testOffsetExists(): void
     {
+        /** @var ArrayObject<array-key, string> $ar */
         $ar        = new ArrayObject();
         $ar['foo'] = 'bar';
         $ar->bar   = 'baz';
@@ -285,12 +274,14 @@ class ArrayObjectTest extends TestCase
     public function testOffsetExistsThrowsExceptionOnProtectedProperty(): void
     {
         $this->expectException(InvalidArgumentException::class);
+        /** @var ArrayObject<array-key, mixed> $ar */
         $ar = new ArrayObject();
         isset($ar->protectedProperties);
     }
 
     public function testOffsetGetOffsetSet(): void
     {
+        /** @var ArrayObject<array-key, string> $ar */
         $ar        = new ArrayObject();
         $ar['foo'] = 'bar';
         $ar->bar   = 'baz';
@@ -304,6 +295,7 @@ class ArrayObjectTest extends TestCase
     public function testOffsetGetThrowsExceptionOnProtectedProperty(): void
     {
         $this->expectException(InvalidArgumentException::class);
+        /** @var ArrayObject<array-key, mixed> $ar */
         $ar = new ArrayObject();
         $ar->protectedProperties;
     }
@@ -311,12 +303,14 @@ class ArrayObjectTest extends TestCase
     public function testOffsetSetThrowsExceptionOnProtectedProperty(): void
     {
         $this->expectException(InvalidArgumentException::class);
+        /** @var ArrayObject<array-key, mixed> $ar */
         $ar                      = new ArrayObject();
         $ar->protectedProperties = null;
     }
 
     public function testOffsetUnset(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar        = new ArrayObject();
         $ar['foo'] = 'bar';
         $ar->bar   = 'foo';
@@ -329,6 +323,7 @@ class ArrayObjectTest extends TestCase
 
     public function testOffsetUnsetMultidimensional(): void
     {
+        /** @var ArrayObject<string, array<string, array<string, mixed>>> $ar */
         $ar        = new ArrayObject();
         $ar['foo'] = ['bar' => ['baz' => 'boo']];
         unset($ar['foo']['bar']['baz']);
@@ -339,17 +334,20 @@ class ArrayObjectTest extends TestCase
     public function testOffsetUnsetThrowsExceptionOnProtectedProperty(): void
     {
         $this->expectException(InvalidArgumentException::class);
+        /** @var ArrayObject<array-key, mixed> $ar */
         $ar = new ArrayObject();
         unset($ar->protectedProperties);
     }
 
     public function testSerializeUnserialize(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar         = new ArrayObject();
         $ar->foo    = 'bar';
         $ar['bar']  = 'foo';
         $serialized = $ar->serialize();
 
+        /** @var ArrayObject<string, string> $ar */
         $ar = new ArrayObject();
         $ar->unserialize($serialized);
 
@@ -373,6 +371,8 @@ class ArrayObjectTest extends TestCase
         $function = static function ($a, $b): int {
             $a = preg_replace('@^(a|an|the) @', '', $a);
             $b = preg_replace('@^(a|an|the) @', '', $b);
+            self::assertNotNull($a);
+            self::assertNotNull($b);
             return strcasecmp($a, $b);
         };
 
@@ -388,6 +388,7 @@ class ArrayObjectTest extends TestCase
      */
     public function testSerializationRestoresProperties(): void
     {
+        /** @var ArrayObject<string, string> $ar */
         $ar        = new ArrayObject();
         $ar->foo   = 'bar';
         $ar['bar'] = 'foo';
