@@ -18,7 +18,7 @@ class IntlTest extends CommonStringWrapperTest
             try {
                 new Intl('utf-8');
                 $this->fail('Missing expected Laminas\Stdlib\Exception\ExtensionNotLoadedException');
-            } catch (Exception\ExtensionNotLoadedException $e) {
+            } catch (Exception\ExtensionNotLoadedException) {
                 $this->markTestSkipped('Missing ext/intl');
             }
         }
@@ -38,6 +38,8 @@ class IntlTest extends CommonStringWrapperTest
             $encoding           = array_shift($supportedEncodings);
         }
 
+        self::assertIsString($encoding);
+
         if (! Intl::isSupported($encoding, $convertEncoding)) {
             return false;
         }
