@@ -14,10 +14,7 @@ class TestOptionsWithoutGetter extends AbstractOptions
     /** @var mixed */
     protected $foo;
 
-    /**
-     * @param mixed $value
-     */
-    public function setFoo($value): void
+    public function setFoo(mixed $value): void
     {
         $this->foo = $value;
     }
